===========
psh-environ
===========

Provide environment hooks for Python Platform.sh projects.

.. start-badges

.. list-table::
    :stub-columns: 1

    * - docs
      - | |docs|
    * - tests
      - | |travis| |requires|
        | |coveralls| |codecov| |scrutinizer-coverage| |codeclimate-coverage|
        | |scrutinizer| |code-intelligence| |codacy| |codeclimate|
    * - package
      - | |version| |wheel| |supported-versions| |supported-implementations|
        | |commits-since|

.. |docs|
    image:: https://readthedocs.org/projects/psh-environ/badge/?version=latest
    :target: https://psh-environ.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. |travis|
    image:: https://travis-ci.com/demosdemon/psh-environ.svg?branch=master
    :target: https://travis-ci.com/demosdemon/psh-environ
    :alt: Travis-CI Build Status

.. |requires|
    image:: https://requires.io/github/demosdemon/psh-environ/requirements.svg?branch=master
    :target: https://requires.io/github/demosdemon/psh-environ/requirements/?branch=master
    :alt: Requirements Status

.. |coveralls|
    image:: https://coveralls.io/repos/github/demosdemon/psh-environ/badge.svg?branch=master
    :target: https://coveralls.io/github/demosdemon/psh-environ?branch=master
    :alt: Coverage Status

.. |codecov|
    image:: https://codecov.io/gh/demosdemon/psh-environ/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/demosdemon/psh-environ
    :alt: Coverage Status

.. |scrutinizer|
    image:: https://scrutinizer-ci.com/g/demosdemon/psh-environ/badges/quality-score.png?b=master
    :target: https://scrutinizer-ci.com/g/demosdemon/psh-environ/?branch=master
    :alt: Scrutinizer Code Quality

.. |scrutinizer-coverage|
    image:: https://scrutinizer-ci.com/g/demosdemon/psh-environ/badges/coverage.png?b=master
    :target: https://scrutinizer-ci.com/g/demosdemon/psh-environ/?branch=master
    :alt: Code Coverage

.. |code-intelligence|
    image:: https://scrutinizer-ci.com/g/demosdemon/psh-environ/badges/code-intelligence.svg?b=master
    :target: https://scrutinizer-ci.com/code-intelligence
    :alt: Code Intelligence Status

.. |codacy|
    image:: https://api.codacy.com/project/badge/Grade/4fe48b5db92d4177958319f4f28a7161
    :target: https://www.codacy.com/app/demosdemon/psh-environ?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=demosdemon/psh-environ&amp;utm_campaign=Badge_Grade
    :alt: Code Quality

.. |codeclimate|
    image:: https://api.codeclimate.com/v1/badges/8c875437c1a6506d9601/maintainability
    :target: https://codeclimate.com/github/demosdemon/psh-environ/maintainability
    :alt: Code Climate Maintainability

.. |codeclimate-coverage|
    image:: https://api.codeclimate.com/v1/badges/8c875437c1a6506d9601/test_coverage
    :target: https://codeclimate.com/github/demosdemon/psh-environ/test_coverage
    :alt: Code Climate Test Coverage

.. |version|
    image:: https://img.shields.io/pypi/v/psh-environ.svg
    :target: https://pypi.org/project/psh-environ
    :alt: PyPI Package Latest Release

.. |wheel|
    image:: https://img.shields.io/pypi/wheel/psh-environ.svg
    :target: https://pypi.org/project/psh-environ
    :alt: PyPI Wheel

.. |supported-versions|
    image:: https://img.shields.io/pypi/pyversions/psh-environ.svg
    :target: https://pypi.org/project/psh-environ
    :alt: Supported Python Versions

.. |supported-implementations|
    image:: https://img.shields.io/pypi/implementation/psh-environ.svg
    :target: https://pypi.org/project/psh-environ
    :alt: Python Implementation

.. |commits-since|
    image:: https://img.shields.io/github/commits-since/demosdemon/psh-environ/v0.0.1.svg
    :target: https://github.com/demosdemon/psh-environ/compare/v0.0.1...master
    :alt: Commits since latest release

.. end-badges
